﻿using BPA.Common.Infrastructure.BizLogs;
using BPA.Common.Infrastructure.Queue;
using BPA.Component.RabbitMQClient.Extensions;
using BPA.Component.RabbitMQClient.Provider;
using BPA.SaaS.BizLog.Api.Model;
using BPA.SaaS.BizLog.Api.Service.Queue;
using Microsoft.Extensions.DependencyInjection;

namespace BPA.SaaS.BizLog.Api.Bootstrap
{
    /// <summary>
    /// RabbitMQ配置 
    /// </summary>
    public static class SetupRabbitMqConfig
    {
        /// <summary>
        /// 使用消息队列
        /// </summary>
        /// <param name="services"></param>
        /// <returns></returns>
        public static IServiceCollection AddRabbitMQ(this IServiceCollection services)
        {
            services.AddRabbitMQProvider(sp => sp.GetService<BizLogApiConfig>()?.RabbitMqConfig);
            services.AddRabbitMQConsumer<BizLogConsumerService, BaseBizLogMsgBody>();

            return services;
        }

        /// <summary>
        /// 预热消息队列
        /// </summary>
        /// <param name="serviceProvider"></param>
        /// <returns></returns>
        public static IServiceProvider PreHeatRunRabbitMQ(this IServiceProvider serviceProvider)
        {
            var rabbitMqProvider = serviceProvider.UseRabbitMQProvider<RabbitMQProvider>();

            var createBizLogQueueConfig = rabbitMqProvider.BuildQueueConfig(MqNameConfig.BizLogQueue, MqNameConfig.BizLogExchange);
            createBizLogQueueConfig.UseQueue();
            createBizLogQueueConfig.UseMultipleConsumer<BaseBizLogMsgBody, BizLogConsumerService>(3);

            return serviceProvider;
        }
    }
}