﻿using BPA.Component.RedisClient;
using BPA.SaaS.BizLog.Api.Model;
using Microsoft.Extensions.DependencyInjection;

namespace BPA.SaaS.BizLog.Api.Bootstrap;

/// <summary>
/// redis DI配置
/// </summary>
public static class SetupRedisConfig
{
    /// <summary>
    /// 注入redis
    /// </summary>
    /// <param name="services"></param>
    public static void AddRedis(this IServiceCollection services)
    {
        services.UseRedisSingleton(sp => GetRedisSingletonConnectionString(sp.GetService<BizLogApiConfig>()!));
    }

    /// <summary>
    /// 预热redis
    /// </summary>
    /// <param name="serviceProvider"></param>
    public static void PreHeatRunRedis(this IServiceProvider serviceProvider)
    {
        var config = serviceProvider.GetService<BizLogApiConfig>();

        // 添加配置改变时的事件
        if (config != null)
            config.OnConfigChange += (stockWebApiConfig, key, _, _, _) =>
            {
                if (nameof(stockWebApiConfig.RedisConfig) != key) return;
                var conStr = GetRedisSingletonConnectionString(stockWebApiConfig);

                //单个redis时 配置变化 触发生成新的实例
                RedisConfigExtensions.OnRedisSingletonConnectionStringChange(conStr);
            };
    }

    /// <summary>
    /// 获取单例 Redis 连接字符串
    /// </summary>
    /// <param name="config"></param>
    /// <returns></returns>
    private static string GetRedisSingletonConnectionString(BizLogApiConfig config) =>
        config.RedisConfig[new Random().Next(0, config.RedisConfig.Count)];
}